@@ -9,6 +9,7 @@ import requests
 from pprint import pprint
 import botocore
 from urllib.parse import urlparse
+import base64
 
 def extract_domain(url):
     parsed_domain = urlparse(url)
@@ -238,13 +239,20 @@ class Resources:
         assert testfunc (self, inst)
         return image
 
-    def update_template (self, image):
+    def update_template (self, image, user_data = None):
         print ('applying {} to template...'.format (image.id))
         latest = self.get_latest_template_version ()
+        template_data = {'ImageId': image.id}
+        if user_data:
+            if isinstance (user_data, list):
+                user_data = "\n".join (user_data)
+            user_data = base64.b64encode (user_data.encode ('utf8')).decode ('ascii')
+            template_data ['UserData'] = user_data
+
         ec2cli.create_launch_template_version (
             LaunchTemplateName = self.LAUNCH_TEMPLATE,
             SourceVersion = str (latest ['VersionNumber']),
-            LaunchTemplateData = {'ImageId': image.id}
+            LaunchTemplateData = template_data
         )
         latest = self.get_latest_template_version ()
         print ('new launch template version created: {}'.format (latest ['VersionNumber']))
